pub struct PlayerController { /* private fields */ }Expand description
This type allows you to control the player from one thread, while rendering it on another.
Implementations
sourceimpl PlayerController
impl PlayerController
sourcepub fn play(&self) -> bool
pub fn play(&self) -> bool
Start the playback.
Retuns true if started or already playing; false otherwise.
sourcepub fn is_playing(&self) -> bool
pub fn is_playing(&self) -> bool
sourcepub fn set_position(&self, value: f64)
pub fn set_position(&self, value: f64)
Set the playing position. In range [0.0, 1.0].
Will take effect only if a file is opened and it’s not empty.
sourcepub fn new_position_observer(&self) -> PositionObserver
pub fn new_position_observer(&self) -> PositionObserver
initialize a new PositionObserver.
sourcepub fn tempo(&self) -> Option<f32>
pub fn tempo(&self) -> Option<f32>
Get the tempo (in beats per minute).
Returns None if file is not set.
sourcepub fn set_volume(&mut self, volume: f32)
pub fn set_volume(&mut self, volume: f32)
Set master volume.
sourcepub fn set_file(
&mut self,
path: Option<impl Into<PathBuf>>,
) -> Result<(), Box<dyn Error>>
pub fn set_file( &mut self, path: Option<impl Into<PathBuf>>, ) -> Result<(), Box<dyn Error>>
Set a MIDI file.
The parameter is Option<&str>, where Some value is actual path and None is for
offloading.
sourcepub fn note_off_all(&mut self)
pub fn note_off_all(&mut self)
Send note off message for all notes (aka Panic)